Learn R Programming

lsr (version 1.0.0)

print.gofTest: Print goodness of fit test results

Description

Prints the results of a chi-square goodness of fit test in a readable format. This function is called automatically whenever a result from goodnessOfFitTest is displayed.

Usage

# S3 method for gofTest
print(x, ...)

Value

Invisibly returns x unchanged.

Arguments

x

A goodness of fit test result, as returned by goodnessOfFitTest.

...

Additional arguments (unused, included for compatibility).